from setuptools import setup, find_packages

setup(
    name="pywright-gpt-tts",
    version="0.0.1",
    packages=find_packages(),
    python_requires=">=3.9",
    description="Python Module for Free ChatGPT TTS",
    author="Abdullah Al Jaber",
)
